import os
import re
from setuptools import setup

__name__ = 'gohlkegrabber'

version_fn = os.path.join(__name__, "_version.py")
__version__ = "unknown"
try:
    version_line = open(version_fn, "rt").read()
except EnvironmentError:
    pass # no version file
else:
    version_regex = r"^__version__ = ['\"]([^'\"]*)['\"]"
    m = re.search(version_regex, version_line, re.M)
    if m:
        __version__ = m.group(1)
    else:
        print(f'unable to find version in {version_fn}')
        raise RuntimeError(f'If {version_fn} exists, it is required to be well-formed')

with open("README.md", "r") as rm:
    long_description = rm.read()

setup(
  name=__name__,
  packages=['gohlkegrabber'],
  version=__version__,
  license='MIT',
  description='Simple script to download .whl packages from www.lfd.uci.edu/~gohlke/pythonlibs.',
  long_description=long_description,
  long_description_content_type='text/markdown',
  author='BMT, Jaap van der Velde',
  author_email='jaap.vandervelde@bmtglobal.com',
  url='https://github.com/jaapvandervelde/gohlkegrabber',
  download_url='https://github.com/jaapvandervelde/gohlkegrabber/archive/v'+__version__+'.tar.gz',
  keywords=['package', 'download', 'gohlke', 'wheel'],
  install_requires=[
      'lxml>=4.4.2'
  ],
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.6',
  ],
  entry_points={
    'console_scripts': ['ggrab=gohlkegrabber:cli_entry_point'],
  }
)



from gohlkegrabber.gohlkegrabber import version_compare
from unittest import TestCase


class TestVersionCompare(TestCase):
    def _all_ops(self, lesser, greater, size):
        self.assertTrue(version_compare(lesser, '==', lesser),
                        f'{size} digit versions {lesser} == {lesser}')
        self.assertFalse(version_compare(lesser, '==', greater),
                         f'{size} digit versions not {lesser} == {greater}')

        self.assertTrue(version_compare(lesser, '<=', lesser),
                        f'equal {size} digit versions {lesser} <= {lesser}')
        self.assertTrue(version_compare(lesser, '<=', greater),
                        f'lesser {size} digit versions {lesser} <= {greater}')
        self.assertFalse(version_compare(greater, '<=', lesser),
                         f'greater {size} digit versions not {greater} <= {lesser}')

        self.assertTrue(version_compare(lesser, '>=', lesser),
                        f'equal {size} digit versions  {lesser} >= {lesser}')
        self.assertTrue(version_compare(greater, '>=', lesser),
                        f'greater {size} digit versions {greater} >= {lesser}')
        self.assertFalse(version_compare(lesser, '>=', greater),
                         f'lesser {size} digit versions not {lesser} >= {greater}')

        self.assertTrue(version_compare(greater, '>', lesser),
                        f'greater {size} digit versions {greater} > {lesser}')
        self.assertFalse(version_compare(lesser, '>', lesser),
                         f'equal {size} digit versions not  {lesser} > {lesser}')
        self.assertFalse(version_compare(lesser, '>', greater),
                         f'lesser {size} digit versions not {lesser} > {greater}')

        self.assertTrue(version_compare(lesser, '<', greater),
                        f'lesser {size} digit versions {lesser} < {greater}')
        self.assertFalse(version_compare(lesser, '<', lesser),
                         f'equal {size} digit versions not  {lesser} < {lesser}')
        self.assertFalse(version_compare(greater, '<', lesser),
                         f'greater {size} digit versions not {greater} <>=> {lesser}')

    def test_single(self):
        self._all_ops('1', '2', 'single')
        self._all_ops('1', '12', 'single')
        self._all_ops('3', '21', 'single')

    def test_double(self):
        self._all_ops('1.1', '2.1', 'double')
        self._all_ops('1.1', '2.0', 'double')
        self._all_ops('1.0', '1.1', 'double')
        self._all_ops('1', '1.1', 'double')
        self._all_ops('1.1', '2', 'double')
        self._all_ops('1.2', '1.12', 'double')

    def test_triple(self):
        self._all_ops('1.0.1', '1.0.2', 'triple')
        self._all_ops('1.0.2', '1.1.0', 'triple')
        self._all_ops('1.1.1', '2.1.1', 'triple')
        self._all_ops('1.0.0', '1.1', 'triple')
        self._all_ops('2.1', '2.1.1', 'triple')
        self._all_ops('2.1.2', '2.1.10', 'double')

    def test_mixed(self):
        self._all_ops('1', '1a', 'mixed')
        self._all_ops('1a', '1b', 'mixed')
        self._all_ops('3a', '21', 'mixed')
        self._all_ops('1.0', '1.0b', 'mixed')
        self._all_ops('1.0a', '1.0b', 'mixed')
        self._all_ops('1.0.0a', '1.0.0b', 'mixed')
